# JBZD imgcat
This small script prints random image from jbzd.pl main page to terminal.

Currently it only supports iTerm2 - [uses inline image protocol](https://iterm2.com/documentation-images.html)

## Source
https://github.com/leszekbulawa/jbzd_imgcat

## Installation
`pip3 install jbzd_imgcat`

## Usage
`jbzd_imgcat`

## TODO
- improve range and randomness of images
- support more terminal emulators
- wheel
- exception handling :)
